# -*- coding: utf-8 -*-
"""
app.admin.views
~~~~~~~~~~~~~~~

This module customizes the admin views.

:copyright: (c) 2017 European Spallation Source ERIC
:license: BSD 2-Clause, see LICENSE for more details.

"""
from flask_admin.contrib import sqla
from flask_login import current_user
from ..models import Item, User, Group
from .. import utils


class AdminModelView(sqla.ModelView):

    def is_accessible(self):
        return current_user.is_authenticated and current_user.is_admin


class GroupAdmin(AdminModelView):
    can_create = False
    can_edit = False
    can_delete = False

    def __init__(self, session):
        super().__init__(Group, session)


class UserAdmin(AdminModelView):
    can_create = False
    can_edit = False
    can_delete = False

    def __init__(self, session):
        super().__init__(User, session)


class ItemAdmin(AdminModelView):

    def __init__(self, session):
        super().__init__(Item, session)

    def on_model_change(self, form, model, is_created):
        """Update the hash"""
        # The hash is supposed to be computed in the __init__ method
        # of the Item class but flask-admin doesn't pass any parameter
        # when creating a class - we do it here instead
        model.hash = utils.compute_hash(model.serial_number)
