# -*- coding: utf-8 -*-
"""
app.main.views
~~~~~~~~~~~~~~

This module implements the main blueprint.

:copyright: (c) 2017 European Spallation Source ERIC
:license: BSD 2-Clause, see LICENSE for more details.

"""
from flask import Blueprint, render_template, jsonify
from flask_login import login_required
from ..extensions import db
from ..models import Action, Manufacturer, Model, Location, Status, Item
from .. import utils

bp = Blueprint('main', __name__)


# Declare custom error handlers for all views
@bp.app_errorhandler(404)
def not_found_error(error):
    return render_template('404.html'), 404


@bp.app_errorhandler(500)
def internal_error(error):
    return render_template('500.html'), 500


@bp.app_errorhandler(utils.InventoryError)
def handle_inventory_error(error):
    response = jsonify(error.to_dict())
    response.status_code = error.status_code
    return response


@bp.route('/_retrieve_items')
@login_required
def retrieve_items():
    items = Item.query.order_by(Item._created)
    data = [[item.id,
             item.serial_number,
             item.name,
             utils.format_field(item.manufacturer),
             utils.format_field(item.model),
             utils.format_field(item.location),
             utils.format_field(item.status),
             utils.format_field(item._updated),
             ] for item in items]
    return jsonify(data=data)


@bp.route('/')
@login_required
def index():
    return render_template('index.html')


@bp.route('/qrcodes')
@login_required
def qrcodes():
    codes = {}
    for model in (Action, Manufacturer, Model, Location, Status):
        items = db.session.query(model).order_by(model.name)
        images = [{'name': item.name,
                   'data': utils.image_to_base64(item.image())}
                  for item in items]
        codes[model.__name__] = images
    return render_template('qrcodes.html', codes=codes)
